asset

package module
v0.0.0-...-195517b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 7, 2025 License: MIT Imports: 1 Imported by: 7

README

This is a hard fork of amitybell/piper-asset.

The original project simply defines an Asset type within a separate Go module in order to resolve a dependency management issue.

This fork makes no meaningful changes to the source code, only to documentation.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Asset

type Asset struct {
	// Name is the name of the asset
	Name string
	// FS is the embedded FS containing the distributed files
	FS fs.FS
}

Asset describes an embedded asset used in github.com/piper-tts-go/piper-go

Jump to